@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -56,10 +56,10 @@ typedef enum _ze_intel_device_module_dp_exp_flag_t {
 ///       `pNext` member of ::ze_device_module_properties_t.
 /// @brief Device module dot product properties
 typedef struct _ze_intel_device_module_dp_exp_properties_t {
-    ze_structure_type_ext_t stype = ZE_STRUCTURE_INTEL_DEVICE_MODULE_DP_EXP_PROPERTIES; ///< [in] type of this structure
-    void *pNext;                                                                        ///< [in,out][optional] must be null or a pointer to an extension-specific
-                                                                                        ///< structure (i.e. contains sType and pNext).
-    ze_intel_device_module_dp_exp_flags_t flags;                                        ///< [out] 0 (none) or a valid combination of ::ze_intel_device_module_dp_flag_t
+    ze_structure_type_ext_t stype;               ///< [in] type of this structure
+    void *pNext;                                 ///< [in,out][optional] must be null or a pointer to an extension-specific
+                                                 ///< structure (i.e. contains sType and pNext).
+    ze_intel_device_module_dp_exp_flags_t flags; ///< [out] 0 (none) or a valid combination of ::ze_intel_device_module_dp_flag_t
 } ze_intel_device_module_dp_exp_properties_t;
 
 #ifndef ZE_INTEL_COMMAND_LIST_MEMORY_SYNC
@@ -175,17 +175,6 @@ typedef enum _zex_intel_queue_copy_operations_offload_hint_exp_version_t {
     ZEX_INTEL_QUEUE_COPY_OPERATIONS_OFFLOAD_HINT_EXP_VERSION_FORCE_UINT32 = 0x7fffffff
 } zex_intel_queue_copy_operations_offload_hint_exp_version_t;
 
-#if ZE_API_VERSION_CURRENT_M <= ZE_MAKE_VERSION(1, 13)
-
-///////////////////////////////////////////////////////////////////////////////
-/// @brief Command queue flag for enabling copy operations offload
-///
-/// If set, try to offload copy operations to different engines. Applicable only for compute queues.
-/// This is only a hint. Driver may ignore it per append call, based on platform capabilities or internal heuristics.
-#define ZE_COMMAND_QUEUE_FLAG_COPY_OFFLOAD_HINT ZE_BIT(2)
-
-#endif // ZE_API_VERSION_CURRENT_M <= ZE_MAKE_VERSION(1, 13)
-
 #ifndef ZE_INTEL_GET_DRIVER_VERSION_STRING_EXP_NAME
 /// @brief Extension name for query to read the Intel Level Zero Driver Version String
 #define ZE_INTEL_GET_DRIVER_VERSION_STRING_EXP_NAME "ZE_intel_get_driver_version_string"
@@ -353,7 +342,7 @@ typedef enum _ze_intel_kernel_get_binary_exp_version_t {
 
 } ze_intel_kernel_get_binary_exp_version_t;
 
-ZE_APIEXPORT ze_result_t ZE_APICALL
+ze_result_t ZE_APICALL
 zeIntelKernelGetBinaryExp(
     ze_kernel_handle_t hKernel, ///< [in] Kernel handle
     size_t *pSize,              ///< [in, out] pointer to variable with size of GEN ISA binary
@@ -581,238 +570,41 @@ typedef struct _ze_queue_priority_desc_t {
     int priority;                  ///< [in] priority of the queue
 } ze_queue_priority_desc_t;
 
-/// @brief Get default context associated with default driver
-///
-/// @details
-///     - The application may call this function from simultaneous threads.
-///     - The implementation of this function should be lock-free.
-///     - Default context contains all devices within default driver instance
-/// @returns
-///     - Context handle associated with default driver
-ZE_APIEXPORT ze_context_handle_t ZE_APICALL zerGetDefaultContext();
-
-/// @brief Get Device Identifier
-///
-/// @details
-///     - The application may call this function from simultaneous threads.
-///     - The implementation of this function should be lock-free.
-///     - Returned identifier is a 32-bit unsigned integer that is unique to the driver.
-///     - The identifier can be used then in zerTranslateIdentifierToDeviceHandle to get the device handle.
-/// @returns
-///     - 32-bit unsigned integer identifier
-ZE_APIEXPORT uint32_t ZE_APICALL zerTranslateDeviceHandleToIdentifier(ze_device_handle_t hDevice); ///< [in] handle of the device
-
-/// @brief Translate Device Identifier to Device Handle from default Driver
-///
-/// @details
-///    - The application may call this function from simultaneous threads.
-///    - The implementation of this function should be lock-free.
-///    - Returned device is associated to default driver handle.
-/// @returns
-///     - device handle associated with the identifier
-ZE_APIEXPORT ze_device_handle_t ZE_APICALL zerTranslateIdentifierToDeviceHandle(uint32_t identifier); ///< [in] integer identifier of the device
+///////////////////////////////////////////////////////////////////////////////
+#ifndef ZE_INTEL_XE_DEVICE_PROPERTIES_EXP_NAME
+/// @brief Intel Xe device properties driver extension name
+#define ZE_INTEL_XE_DEVICE_PROPERTIES_EXP_NAME "ZE_intel_experimental_xe_device_properties"
+#endif // ZE_INTEL_XE_DEVICE_PROPERTIES_EXP_NAME
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Retrieves a string describing the last error code returned by the
-///        default driver in the current thread.
-///
-/// @details
-///     - String returned is thread local.
-///     - String is only updated on calls returning an error, i.e., not on calls
-///       returning ::ZE_RESULT_SUCCESS.
-///     - String may be empty if driver considers error code is already explicit
-///       enough to describe cause.
-///     - Memory pointed to by ppString is owned by the driver.
-///     - String returned is null-terminated.
-///
-/// @returns
-///     - ::ZE_RESULT_SUCCESS
-///     - ::ZE_RESULT_ERROR_UNINITIALIZED
-///     - ::ZE_RESULT_ERROR_DEVICE_LOST
-///     - ::ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY
-///     - ::ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY
-///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
-///         + `nullptr == ppString`
-ZE_APIEXPORT ze_result_t ZE_APICALL
-zerGetLastErrorDescription(
-    const char **ppString ///< [in,out] pointer to a null-terminated array of characters describing
-                          ///< cause of error.
-);
+/// @brief Intel Xe device compute unit properties extension Version(s)
+typedef enum _ze_intel_xe_device_exp_properties_version_t {
+    ZE_INTEL_XE_DEVICE_EXP_PROPERTIES_VERSION_1_0 = ZE_MAKE_VERSION(1, 0),     ///< version 1.0
+    ZE_INTEL_XE_DEVICE_EXP_PROPERTIES_VERSION_CURRENT = ZE_MAKE_VERSION(1, 0), ///< latest known version
+    ZE_INTEL_XE_DEVICE_EXP_PROPERTIES_VERSION_FORCE_UINT32 = 0x7fffffff
 
-#if ZE_API_VERSION_CURRENT_M <= ZE_MAKE_VERSION(1, 13)
-
-/// @brief Get default context associated with driver
-///
-/// @details
-///     - The application may call this function from simultaneous threads.
-///     - The implementation of this function should be lock-free.
-///     - Default context contains all devices within driver instance
-/// @returns
-///     - Context handle associated with driver
-ze_context_handle_t ZE_APICALL zeDriverGetDefaultContext(ze_driver_handle_t hDriver); ///> [in] handle of the driver
-
-/// @brief Global device synchronization
-///
-/// @details
-///    - The application may call this function from simultaneous threads.
-///    - The implementation of this function should be lock-free.
-///    - Ensures that everything that was submitted to the device is completed.
-///    - Ensures that all submissions in all queues on device are completed.
-///    - It is not allowed to call this function while some command list are in graph capture mode.
-///    - Returns error if error is detected during execution on device.
-///    - Hangs indefinitely if GPU execution is blocked on non signaled event.
-///
-/// @returns
-///     - ::ZE_RESULT_SUCCESS
-///     - ::ZE_RESULT_ERROR_DEVICE_LOST
-ze_result_t ZE_APICALL zeDeviceSynchronize(ze_device_handle_t hDevice); ///> [in] handle of the device
-
-/// @brief Append with arguments
-///
-/// @details
-///    - The application may call this function from simultaneous threads.
-///    - The implementation of this function should be lock-free.
-///    - Appends kernel to command list with arguments.
-///    - Kernel object state is updated with new arguments, as if separate zeKernelSetArgumentValue were called.
-///    - If argument is SLM (size), then SLM size in bytes for this resource is provided under pointer on specific index and its type is size_t.
-///    - If argument is an immediate type (i.e. structure, non pointer type), then values under pointer must contain full size of immediate type.
-///
-/// @returns
-///     - ::ZE_RESULT_SUCCESS
-///     - ::ZE_RESULT_ERROR_DEVICE_LOST
-///     - ::ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY
-///     - ::ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY
-///     - ::ZE_RESULT_ERROR_INVALID_GROUP_SIZE_DIMENSION
-///     - ::ZE_RESULT_ERROR_INVALID_NULL_HANDLE
-///         + `nullptr == hCommandList`
-///         + `nullptr == hKernel`
-///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
-///         + `nullptr == pArguments`
-///     - ::ZE_RESULT_ERROR_INVALID_SYNCHRONIZATION_OBJECT
-///     - ::ZE_RESULT_ERROR_INVALID_SIZE
-///         + `(nullptr == phWaitEvents) && (0 < numWaitEvents)`
-typedef struct _ze_group_size_t {
-    uint32_t groupSizeX; ///< [in] local work-group size in X dimension
-    uint32_t groupSizeY; ///< [in] local work-group size in Y dimension
-    uint32_t groupSizeZ; ///< [in] local work-group size in Z dimension
-
-} ze_group_size_t;
-
-ze_result_t ZE_APICALL zeCommandListAppendLaunchKernelWithArguments(
-    ze_command_list_handle_t hCommandList, ///< [in] handle of the command list
-    ze_kernel_handle_t hKernel,            ///< [in] handle of the kernel object
-    const ze_group_count_t groupCounts,    ///< [in] thread group counts
-    const ze_group_size_t groupSizes,      ///< [in] thread group sizes
-    void **pArguments,                     ///< [in] kernel arguments; pointer to list where each argument represents a pointer to the argument value on specific index
-    const void *pNext,                     ///< [in][optional] extensions
-    ze_event_handle_t hSignalEvent,        ///< [in][optional] handle of the event to signal on completion
-    uint32_t numWaitEvents,                ///< [in][optional] number of events to wait on before launching
-    ze_event_handle_t *phWaitEvents);      ///< [in][optional][range(0, numWaitEvents)] handle of the events to wait on before launching
+} ze_intel_xe_device_exp_properties_version_t;
 
 ///////////////////////////////////////////////////////////////////////////////
-/// @brief Extension descriptor for cooperative kernel launch via pNext chain.
-/// @details
-///     - This structure can be passed through pNext to zeCommandListAppendLaunchKernelWithParameters
-typedef struct _ze_command_list_append_launch_kernel_param_cooperative_desc_t {
-    ze_structure_type_ext_t stype; ///< [in] Type of this structure (e.g. ZE_STRUCTURE_TYPE_COMMAND_LIST_APPEND_PARAM_COOPERATIVE_DESC)
-    const void *pNext;             ///< [in][optional] Pointer to the next extension-specific structure
-    ze_bool_t isCooperative;       ///< [in] Indicates if the kernel should be launched as cooperative
-} ze_command_list_append_launch_kernel_param_cooperative_desc_t;
-/// @brief Append with parameters
+/// @brief Intel Xe device compute unit properties
 ///
 /// @details
-///    - The application may call this function from simultaneous threads.
-///    - The implementation of this function should be lock-free.
-///    - Appends kernel to command list with additional parameters via pNext chain.
-///    - Allows passing core and extension descriptors (e.g. cooperative kernel).
-///
-/// @returns
-///     - ::ZE_RESULT_SUCCESS
-///     - ::ZE_RESULT_ERROR_DEVICE_LOST
-///     - ::ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY
-///     - ::ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY
-///     - ::ZE_RESULT_ERROR_UNSUPPORTED_FEATURE
-///     - ::ZE_RESULT_ERROR_INVALID_NULL_HANDLE
-///         + `nullptr == hCommandList`
-///         + `nullptr == hKernel`
-///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
-///         + `nullptr == pGroupCounts`
-///     - ::ZE_RESULT_ERROR_INVALID_SYNCHRONIZATION_OBJECT
-///     - ::ZE_RESULT_ERROR_INVALID_SIZE
-///         + `(nullptr == phWaitEvents) && (0 < numWaitEvents)`
-ZE_APIEXPORT ze_result_t ZE_APICALL zeCommandListAppendLaunchKernelWithParameters(
-    ze_command_list_handle_t hCommandList, ///< [in] handle of the command list
-    ze_kernel_handle_t hKernel,            ///< [in] handle of the kernel object
-    const ze_group_count_t *pGroupCounts,  ///< [in] thread group launch arguments
-    const void *pNext,                     ///< [in][optional] additional parameters (pNext chain)
-    ze_event_handle_t hSignalEvent,        ///< [in][optional] handle of the event to signal on completion
-    uint32_t numWaitEvents,                ///< [in][optional] number of events to wait on before launching
-    ze_event_handle_t *phWaitEvents        ///< [in][optional][range(0, numWaitEvents)] handle of the events to wait on before launching
-);
+///     - This structure should be passed to ::zeDeviceGetProperties, via the `pNext` member of ::ze_device_properties_t
 
-#endif // ZE_API_VERSION_CURRENT_M <= ZE_MAKE_VERSION(1, 13)
+typedef struct _ze_intel_xe_device_exp_properties_t {
+    ze_structure_type_ext_t stype;              ///< [in] type of this structure
+    void *pNext;                                ///< [in][optional] must be null or a pointer to extension-specific structure
+    uint32_t numXeStacks;                       ///< [out] number of Stacks (Tiles)
+    uint32_t numXeRegionsPerStack;              ///< [out] number of Regions per stack
+    uint32_t numXeClustersPerRegion;            ///< [out] number of Clusters (Slices) per Region
+    uint32_t numXeCorePerCluster;               ///< [out] number of XE Cores per Cluster
+    uint32_t numExecutionEnginesPerXeCore;      ///< [out] number of Execution Engines (EUs) per XE Core
+    uint32_t maxNumHwThreadsPerExecutionEngine; ///< [out] maximal number of HW threads per Execution Engine
+    uint32_t maxNumLanesPerHwThread;            ///< [out] maximal number of lanes (virtual SIMD size) per HW thread
+} ze_intel_xe_device_exp_properties_t;
 
 #if defined(__cplusplus)
 } // extern "C"
 #endif
 
-static const ze_device_mem_alloc_desc_t defaultIntelDeviceMemDesc = {
-    ZE_STRUCTURE_TYPE_DEVICE_MEM_ALLOC_DESC, // stype
-    nullptr,                                 // pNext
-    ZE_DEVICE_MEM_ALLOC_FLAG_BIAS_CACHED,    // flags
-    0                                        // ordinal
-};
-
-static const ze_host_mem_alloc_desc_t defaultIntelHostMemDesc = {
-    ZE_STRUCTURE_TYPE_HOST_MEM_ALLOC_DESC,                                             // stype
-    nullptr,                                                                           // pNext
-    ZE_HOST_MEM_ALLOC_FLAG_BIAS_CACHED | ZE_HOST_MEM_ALLOC_FLAG_BIAS_INITIAL_PLACEMENT // flags
-};
-
-static const ze_command_queue_desc_t defaultIntelCommandQueueDesc = {
-    ZE_STRUCTURE_TYPE_COMMAND_QUEUE_DESC,                                     // stype
-    nullptr,                                                                  // pNext
-    0,                                                                        // ordinal
-    0,                                                                        // index
-    ZE_COMMAND_QUEUE_FLAG_IN_ORDER | ZE_COMMAND_QUEUE_FLAG_COPY_OFFLOAD_HINT, // flags
-    ZE_COMMAND_QUEUE_MODE_ASYNCHRONOUS,                                       // mode
-    ZE_COMMAND_QUEUE_PRIORITY_NORMAL                                          // priority
-};
-
-#if ZE_API_VERSION_CURRENT_M <= ZE_MAKE_VERSION(1, 13)
-
-///////////////////////////////////////////////////////////////////////////////
-#ifndef ZE_EXTERNAL_MEMORY_MAPPING_EXT_NAME
-/// @brief External Memory Mapping Extension Name
-#define ZE_EXTERNAL_MEMORY_MAPPING_EXT_NAME "ZE_extension_external_memmap_sysmem"
-
-///////////////////////////////////////////////////////////////////////////////
-/// @brief External Memory Mapping Extension Version(s)
-typedef enum _ze_external_memmap_sysmem_ext_version_t {
-    ZE_EXTERNAL_MEMMAP_SYSMEM_EXT_VERSION_1_0 = ZE_MAKE_VERSION(1, 0),     ///< version 1.0
-    ZE_EXTERNAL_MEMMAP_SYSMEM_EXT_VERSION_CURRENT = ZE_MAKE_VERSION(1, 0), ///< latest known version
-    ZE_EXTERNAL_MEMMAP_SYSMEM_EXT_VERSION_FORCE_UINT32 = 0x7fffffff        ///< Value marking end of ZE_EXTERNAL_MEMMAP_SYSMEM_EXT_VERSION_* ENUMs
-
-} ze_external_memmap_sysmem_ext_version_t;
-
-///////////////////////////////////////////////////////////////////////////////
-/// @brief Maps external system memory for an allocation
-///
-/// @details
-///     - This structure may be passed to ::zeMemAllocHost, via the `pNext`
-///       member of ::ze_host_mem_alloc_desc_t to map system memory for a host
-///       allocation.
-///     - The system memory pointer and size being mapped must be page aligned
-///       based on the supported page sizes on the device.
-typedef struct _ze_external_memmap_sysmem_ext_desc_t {
-    ze_structure_type_ext_t stype; ///< [in] type of this structure
-    const void *pNext;             ///< [in][optional] must be null or a pointer to an extension-specific
-                                   ///< structure (i.e. contains stype and pNext).
-    const void *pSystemMemory;     ///< [in] system memory pointer to map; must be page-aligned.
-    const uint64_t size;           ///< [in] size of the system memory to map; must be page-aligned.
-
-} ze_external_memmap_sysmem_ext_desc_t;
-#endif // ZE_EXTERNAL_MEMORY_MAPPING_EXT_NAME
-
-#endif // ZE_API_VERSION_CURRENT_M <= ZE_MAKE_VERSION(1, 13)
 #endif
